==> crowdin-api-client-1.0.5.tar.gz: crowdin-api-client-1.0.5/crowdin_api/api_resources/__init__.py <==
from .dictionaries.resource import DictionariesResource
from .distributions.resource import DistributionsResource
from .glossaries.resource import GlossariesResource
from .labels.resource import LabelsResource
from .languages.resource import LanguagesResource
from .projects.resource import ProjectsResource
from .reports.resource import ReportsResource
from .screenshots.resource import ScreenshotsResource
from .source_files.resource import SourceFilesResource
from .source_strings.resource import SourceStringsResource
from .storages.resource import StoragesResource
from .string_comments.resource import StringCommentsResource
from .string_translations.resource import StringTranslationsResource
from .tasks.resource import TasksResource
from .translation_memory.resource import TranslationMemoryResource
from .translation_status.resource import TranslationStatusResource
from .translations.resource import TranslationsResource
from .users.resource import UsersResource
from .webhooks.resource import WebhooksResource

__all__ = [
    "DictionariesResource",
    "DistributionsResource",
    "GlossariesResource",
    "LabelsResource",
    "LanguagesResource",
    "ProjectsResource",
    "ReportsResource",
    "ScreenshotsResource",
    "SourceFilesResource",
    "SourceStringsResource",
    "StoragesResource",
    "StringCommentsResource",
    "StringTranslationsResource",
    "TasksResource",
    "TranslationMemoryResource",
    "TranslationStatusResource",
    "TranslationsResource",
    "UsersResource",
    "WebhooksResource",
]

==> crowdin-api-client-1.3.0.tar.gz: crowdin-api-client-1.3.0/crowdin_api/api_resources/__init__.py <==
from .dictionaries.resource import DictionariesResource
from .distributions.resource import DistributionsResource
from .glossaries.resource import GlossariesResource
from .groups.resource import GroupsResource
from .labels.resource import LabelsResource
from .languages.resource import LanguagesResource
from .machine_translation_engines.resource import MachineTranslationEnginesResource
from .projects.resource import ProjectsResource
from .reports.resource import ReportsResource, EnterpriseReportsResource
from .screenshots.resource import ScreenshotsResource
from .source_files.resource import SourceFilesResource
from .source_strings.resource import SourceStringsResource
from .storages.resource import StoragesResource
from .string_comments.resource import StringCommentsResource
from .string_translations.resource import StringTranslationsResource
from .tasks.resource import TasksResource
from .translation_memory.resource import TranslationMemoryResource
from .translation_status.resource import TranslationStatusResource
from .translations.resource import TranslationsResource
from .users.resource import UsersResource, EnterpriseUsersResource
from .webhooks.resource import WebhooksResource

__all__ = [
    "DictionariesResource",
    "DistributionsResource",
    "GlossariesResource",
    "GroupsResource",
    "LabelsResource",
    "LanguagesResource",
    "MachineTranslationEnginesResource",
    "ProjectsResource",
    "ReportsResource",
    "EnterpriseReportsResource",
    "ScreenshotsResource",
    "SourceFilesResource",
    "SourceStringsResource",
    "StoragesResource",
    "StringCommentsResource",
    "StringTranslationsResource",
    "TasksResource",
    "TranslationMemoryResource",
    "TranslationStatusResource",
    "TranslationsResource",
    "UsersResource",
    "EnterpriseUsersResource",
    "WebhooksResource",
]
